jactorch.transforms.coor.transforms
===================================

.. automodule:: jactorch.transforms.coor.transforms

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      CenterCrop
      ColorJitter
      Compose
      DenormalizeCoor
      Grayscale
      Lambda
      LinearTransformation
      Normalize
      NormalizeCoor
      Pad
      PadMultipleOf
      RandomCrop
      RandomGrayscale
      RandomHorizontalFlip
      RandomResizedCrop
      RandomRotation
      RandomVerticalFlip
      Resize
      ToTensor
   
   

   
   
   

   
   
   








.. rubric:: Class CenterCrop
.. autoclass:: CenterCrop
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ColorJitter
.. autoclass:: ColorJitter
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Compose
.. autoclass:: Compose
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DenormalizeCoor
.. autoclass:: DenormalizeCoor
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Grayscale
.. autoclass:: Grayscale
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Lambda
.. autoclass:: Lambda
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LinearTransformation
.. autoclass:: LinearTransformation
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Normalize
.. autoclass:: Normalize
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class NormalizeCoor
.. autoclass:: NormalizeCoor
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Pad
.. autoclass:: Pad
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class PadMultipleOf
.. autoclass:: PadMultipleOf
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomCrop
.. autoclass:: RandomCrop
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomGrayscale
.. autoclass:: RandomGrayscale
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomHorizontalFlip
.. autoclass:: RandomHorizontalFlip
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomResizedCrop
.. autoclass:: RandomResizedCrop
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomRotation
.. autoclass:: RandomRotation
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomVerticalFlip
.. autoclass:: RandomVerticalFlip
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Resize
.. autoclass:: Resize
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ToTensor
.. autoclass:: ToTensor
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







